@@ -1,36 +1,37 @@
-"""Fastapi server"""
-#
-
-from typing import Optional
-
-import os
+"""Run fastapi server."""
+# pylint: disable=invalid-name, duplicate-code, no-name-in-module, broad-except
+# import nest_asyncio
 
 # import sys
 import asyncio
+import os
+from signal import SIG_DFL, SIGINT, signal
+from typing import Optional
 
-# import subprocess as sp
-
-from signal import signal, SIGINT, SIG_DFL
-
+import nest_asyncio
 import portalocker
-import logzero
-from logzero import logger
-
-logzero.loglevel(10)
-
 import uvicorn
+from deepl_scraper_pp.deepl_tr import deepl_tr
 from fastapi import FastAPI, Query
+from get_ppbrowser.get_ppbrowser import get_ppbrowser
+
+# import logzero
+from logzero import logger
 from pydantic import BaseModel
 
+from deepl_fastapi import __version__
+
 # lazy loading LOOP, wait for run_uvicorn to start first
 # import lazy_import
 # get_ppbrowser = lazy_import.lazy_module(get_ppbrowser)
 
-from deepl_scraper_pp.deepl_tr import deepl_tr
-from get_ppbrowser.get_ppbrowser import get_ppbrowser
+
+nest_asyncio.apply()
+port = 8001
 
 
 async def get_page():
+    """Get page."""
     try:
         browser = await get_ppbrowser()
     except Exception as exc:
@@ -55,29 +56,35 @@ async def get_page():
 try:
     LOOP = asyncio.get_event_loop()
     # LOOP = asyncio.get_running_loop()
-except Exception as exc:
-    logger.error("weird: %s", exc)
-    raise SystemExit(1) from exc
+except Exception as exc_:
+    logger.error("weird: %s", exc_)
+    raise SystemExit(1) from exc_
 
 try:
     PAGE = LOOP.run_until_complete(get_page())
-except Exception as exc:
-    logger.error(exc)
-    raise SystemExit("Unable to connect to deepl.com") from exc
+except Exception as exc_:
+    logger.error(exc_)
+    raise SystemExit("Unable to connect to deepl.com") from exc_
 
 
-class Text(BaseModel):
+class Text(BaseModel):  # pylint: disable=too-few-public-methods
+    """Define Text model."""
+
     text: str
     from_lang: Optional[str] = None
     to_lang: Optional[str] = None
     description: Optional[str] = None
 
 
-app = FastAPI(title="deepl-fastapi")
+app = FastAPI(
+    title="deepl-fastapi",
+    version=__version__,
+)
 
 
 @app.post("/text/")
 async def post_text(q: Text):
+    """Post q."""
     text = q.text
     to_lang = q.to_lang
     from_lang = q.from_lang
@@ -85,7 +92,12 @@ async def post_text(q: Text):
 
     # _ = sent_corr(text1, text2)
     try:
-        _ = await deepl_tr(text, from_lang, to_lang, page=PAGE,)
+        _ = await deepl_tr(
+            text,
+            from_lang,
+            to_lang,
+            page=PAGE,
+        )
     except Exception as exc:
         logger.error(exc)
         _ = {"error": True, "message": str(exc)}
@@ -100,7 +112,10 @@ async def get_text(
         max_length=1500,
         min_length=1,
         title="text to translate",
-        description="max. 5000 chars, paragraphs will not be preserved. multiple translations may be provided for short phrases.",
+        description=(
+            "max. 5000 chars, paragraphs will not be preserved."
+            "multiple translations may be provided for short phrases."
+        ),
     ),
     from_lang: Optional[str] = None,
     to_lang: Optional[str] = "zh",
@@ -115,7 +130,12 @@ async def get_text(
         "to_lang": to_lang,
     }
     try:
-        trtext = await deepl_tr(q, from_lang, to_lang, page=PAGE,)
+        trtext = await deepl_tr(
+            q,
+            from_lang,
+            to_lang,
+            page=PAGE,
+        )
     except Exception as exc:
         logger.error(exc)
         trtext = str(exc)
@@ -135,9 +155,11 @@ def run_uvicorn():
     """
     uvicorn.run(
         # app="deepl_fastapi.deepl_server:app",
-        app=app,  # this should work with python -m deepl_fastapi.deepl_server, still "attached to a different loop" error
+        app=app,  # this should work with python -m deepl_fastapi.deepl_server
+        # still "attached to a different loop" error
         host="0.0.0.0",
-        port=8000,
+        # port=8000,
+        port=port,
         # debug=True,
         # reload=True,
         # workers=2,
@@ -216,16 +238,18 @@ if __name__ == "__main__":
 
     try:
         # portalocker.lock(file, portalocker.constants.LOCK_EX)
-        file = open(f"{__file__}.portalocker.lock", "r+")
-        portalocker.lock(file, portalocker.LOCK_EX | portalocker.LOCK_NB)
-        ...
-    except Exception as exc:
-        logger.debug(exc)
+        with open(f"{__file__}.portalocker.lock", "r+", encoding="utf8") as fha:
+            portalocker.lock(fha, portalocker.LOCK_EX | portalocker.LOCK_NB)
+    except Exception as exc_:
+        logger.debug(exc_)
         logger.error("Another copy is running, exiting...")
-        raise SystemExit(1) from exc
+        raise SystemExit(1) from exc_
         # raise
     finally:
         # LOOP.close()
         ...
 
+    logger.debug(
+        "starting uvicorn at port %s, accessible 127.0.0.1:%s/text/q=test", port, port
+    )
     run_uvicorn()
