@@ -3,13 +3,15 @@
 uvicorn deepl_fastapi.deepl_server:app --reload
 """
 from pathlib import Path
-import uvicorn
+from signal import SIG_DFL, SIGINT, signal
+
 import portalocker
-from signal import signal, SIGINT, SIG_DFL
+import uvicorn
 from logzero import logger
 
 
 def run_uvicorn(host="127.0.0.1", port=8000, debug=False, reload=False):
+    """Start uvicorn."""
     uvicorn.run(
         app="deepl_fastapi.deepl_server:app",
         host=host,
@@ -23,6 +25,7 @@ def run_uvicorn(host="127.0.0.1", port=8000, debug=False, reload=False):
 
 
 def main():
+    """Run main."""
     signal(SIGINT, SIG_DFL)
     print("ctrl-C to interrupt")
 
@@ -31,10 +34,9 @@ def main():
     if not Path(lockfile).exists():
         Path(lockfile).touch()
     try:
-        file = open(lockfile, "r+")
-        # portalocker.lock(file, portalocker.constants.LOCK_EX)
-        portalocker.lock(file, portalocker.LOCK_EX | portalocker.LOCK_NB)
-        ...
+        with open(lockfile, "r+", encoding="utf8") as file:
+            # portalocker.lock(file, portalocker.constants.LOCK_EX)
+            portalocker.lock(file, portalocker.LOCK_EX | portalocker.LOCK_NB)
     except Exception as exc:
         logger.debug(exc)
         logger.error("Another copy is running, exiting...")
